<?php

namespace App\Http\Controllers;

use App\Repositories\Task\TaskRepositoryContract;
use App\Repositories\Lead\LeadRepositoryContract;
use App\Repositories\User\UserRepositoryContract;
use App\Repositories\Client\ClientRepositoryContract;
use App\Repositories\Setting\SettingRepositoryContract;

class PagesController extends Controller
{
    protected $users;
    protected $clients;
    protected $settings;
    protected $tasks;
    protected $leads;

    public function __construct(
        UserRepositoryContract $users,
        ClientRepositoryContract $clients,
        SettingRepositoryContract $settings,
        TaskRepositoryContract $tasks,
        LeadRepositoryContract $leads
    ) {
        $this->users    = $users;
        $this->clients  = $clients;
        $this->settings = $settings;
        $this->tasks    = $tasks;
        $this->leads    = $leads;
    }

    /**
     * Dashobard view.
     *
     * @return mixed
     */
    public function dashboard()
    {
        /**
         * Other Statistics.
         */
        $companyname    = $this->settings->getCompanyName();
        $users          = $this->users->getAllUsers();
        $totalClients   = $this->clients->getAllClientsCount();
        $totalTimeSpent = $this->tasks->totalTimeSpent();

        /**
         * Statistics for all-time tasks.
         */
        $alltasks             = $this->tasks->tasks();
        $allCompletedTasks    = $this->tasks->allCompletedTasks();
        $totalPercentageTasks = $this->tasks->percantageCompleted();

        /**
         * Statistics for today tasks.
         */
        $completedTasksToday = $this->tasks->completedTasksToday();
        $createdTasksToday   = $this->tasks->createdTasksToday();

        /**
         * Statistics for tasks this month.
         */
        $taskCompletedThisMonth = $this->tasks->completedTasksThisMonth();

        /**
         * Statistics for tasks each month(For Charts).
         */
        $createdTasksMonthly   = $this->tasks->createdTasksMothly();
        $completedTasksMonthly = $this->tasks->completedTasksMothly();

        /**
         * Statistics for all-time Leads.
         */
        $allleads             = $this->leads->leads();
        $allCompletedLeads    = $this->leads->allCompletedLeads();
        $totalPercentageLeads = $this->leads->percantageCompleted();
        /**
         * Statistics for today leads.
         */
        $completedLeadsToday = $this->leads->completedLeadsToday();
        $createdLeadsToday   = $this->leads->createdLeadsToday();

        /**
         * Statistics for leads this month.
         */
        $leadCompletedThisMonth = $this->leads->completedLeadsThisMonth();

        /**
         * Statistics for leads each month(For Charts).
         */
        $completedLeadsMonthly = $this->leads->createdLeadsMonthly();
        $createdLeadsMonthly   = $this->leads->completedLeadsMonthly();

        return view('pages.dashboard', compact(
            'completedTasksToday',
            'completedLeadsToday',
            'createdTasksToday',
            'createdLeadsToday',
            'createdTasksMonthly',
            'completedTasksMonthly',
            'completedLeadsMonthly',
            'createdLeadsMonthly',
            'taskCompletedThisMonth',
            'leadCompletedThisMonth',
            'totalTimeSpent',
            'totalClients',
            'users',
            'companyname',
            'alltasks',
            'allCompletedTasks',
            'totalPercentageTasks',
            'allleads',
            'allCompletedLeads',
            'totalPercentageLeads'
        ));
    }
}
