<?php

namespace App\Listeners;

use App\Events\LeadAction;
use App\Models\Activity;
use App\Models\Lead;

class LeadActionLog
{
    /**
     * Action the event listener.
     */
    public function __construct()
    {
    }

    /**
     * Handle the event.
     *
     * @param LeadAction $event
     */
    public function handle(LeadAction $event)
    {
        switch ($event->getAction()) {
            case 'created':
                $text = __(':title was created by :creator and assigned to :assignee', [
                    'title'    => $event->getLead()->title,
                    'creator'  => $event->getLead()->creator->name,
                    'assignee' => $event->getLead()->user->name,
                ]);
                break;
            case 'updated_status':
                $text = __('Lead was completed by :username', [
                    'username' => Auth()->user()->name,
                ]);
                break;
            case 'updated_deadline':
                $text = __(':username updated the deadline for this lead', [
                    'username' => Auth()->user()->name,
                ]);
                break;
            case 'updated_assign':
                $text = __(':username assigned lead to :assignee', [
                    'username' => Auth()->user()->name,
                    'assignee' => $event->getLead()->user->name,
                ]);
                break;
            default:
                break;
        }

        $activityinput = array_merge(
            [
                'text'        => $text,
                'user_id'     => Auth()->id(),
                'source_type' => Lead::class,
                'source_id'   => $event->getLead()->id,
                'action'      => $event->getAction(),
            ]
        );

        Activity::create($activityinput);
    }
}
