<?php

namespace App\Listeners;

use App\Events\TaskAction;
use App\Models\Activity;
use App\Models\Task;

class TaskActionLog
{
    /**
     * Create the event listener.
     */
    public function __construct()
    {
    }

    /**
     * Handle the event.
     *
     * @param TaskAction $event
     */
    public function handle(TaskAction $event)
    {
        switch ($event->getAction()) {
            case 'created':
                $text = __(':title was created by :creator and assigned to :assignee', [
                        'title'    => $event->getTask()->title,
                        'creator'  => $event->getTask()->creator->name,
                        'assignee' => $event->getTask()->user->name,
                    ]);
                break;
            case 'updated_status':
                $text = __('Task was completed by :username', [
                        'username' => Auth()->user()->name,
                    ]);
                break;
            case 'updated_time':
                $text = __(':username inserted a new time for this task', [
                        'username' => Auth()->user()->name,
                    ]);

                break;
            case 'updated_assign':
                $text = __(':username assigned task to :assignee', [
                        'username' => Auth()->user()->name,
                        'assignee' => $event->getTask()->user->name,
                    ]);
                break;
            default:
                break;
        }

        $activityinput = array_merge(
            [
                'text'        => $text,
                'user_id'     => Auth()->id(),
                'source_type' => Task::class,
                'source_id'   => $event->getTask()->id,
                'action'      => $event->getAction(),
            ]
        );

        Activity::create($activityinput);
    }
}
